@@ -33,16 +33,10 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 #endif
 #ifdef DEBUG
 				comp_factor_algo,
-#ifdef USE_ZLIB
-				comp_mzlib2_algo,
-#else
-				comp_fail_algo,
-#endif
 				comp_range_algo,
 #else
 				comp_fail_algo,
 				comp_fail_algo,
-				comp_fail_algo,
 #endif
                                 NULL};
 
@@ -59,15 +53,9 @@ char *algorithm_names[256]={	"Uncompressed",
 #endif
 #ifdef DEBUG
 				"Factor Compression",
-#ifdef USE_ZLIB
-				"Second Modified Zlib",
-#else
-				"Unsupported Algorithm (mzlib2)",
-#endif
 				"Range Encoding",
 #else
 				"Unsupported Algorithm (factor)",
-				"Unsupported Algorithm (mzlib2)",
 				"Unsupported Algorithm (range)",
 #endif
 				NULL
