@@ -4,7 +4,9 @@
 #include <stdio.h>
 
 
-
+/*
+	Bubble Sort
+*/
 void int_sort (unsigned int array[], unsigned int listsize) {
 	unsigned int temp,i,j;
 
@@ -21,6 +23,11 @@ void int_sort (unsigned int array[], unsigned int listsize) {
 	}
 }
 
+
+/*
+	I have no idea what this sort is called, if it has a name
+	(I just made one that I thought would work well.)
+*/
 void int_sort_fast (unsigned int array[], unsigned int elements) {
 	unsigned int *hold_array;
 	unsigned int i, x, cnt=0;
